@@ -1,8 +1,8 @@
 package Catty;
 
 use strict;
-use Catalyst;
-#use Catalyst qw/-Debug/;
+#use Catalyst;
+use Catalyst qw/-Debug/;
 use Cwd;
 
 our $VERSION = '0.01';
@@ -51,6 +51,14 @@ sub bonjour : Global {
   return;
 }
 
+sub die : Global {
+  my($self, $context) = @_;
+  my $html = html("Die", "This is the die page");
+  $context->response->content_type("text/html");
+  $context->response->output($html);
+  die "erk!";
+}
+
 sub html {
   my($title, $body) = @_;
   return qq{
